@@ -32,7 +32,7 @@ class Display:
 		"""SCPI: DISPlay:BRIGhtness \n
 		Snippet: driver.display.set_brightness(display_brightness = 1.0) \n
 		Sets or queries the display brightness. \n
-			:param display_brightness: Displays brightness for the instrument. Range: 0.0 to 1.0
+			:param display_brightness: Displays brightness for the instrument.
 		"""
 		param = Conversions.decimal_value_to_str(display_brightness)
 		self._core.io.write(f'DISPlay:BRIGhtness {param}')
