@@ -11,13 +11,13 @@ class Text:
 		self._core = core
 		self._base = CommandsGroup("text", core, parent)
 
-	def set_data(self, current: str) -> None:
+	def set_data(self, custom_message: str) -> None:
 		"""SCPI: DISPlay[:WINDow]:TEXT[:DATA] \n
-		Snippet: driver.display.window.text.set_data(current = '1') \n
-		Displays a text message box on the front display. \n
-			:param current: Text message for display.
+		Snippet: driver.display.window.text.set_data(custom_message = '1') \n
+		Shows the text message box on the front display. \n
+			:param custom_message: New value for text message box.
 		"""
-		param = Conversions.value_to_quoted_str(current)
+		param = Conversions.value_to_quoted_str(custom_message)
 		self._core.io.write(f'DISPlay:WINDow:TEXT:DATA {param}')
 
 	def clear(self) -> None:
