@@ -12,22 +12,22 @@ class FormatPy:
 		self._core = core
 		self._base = CommandsGroup("formatPy", core, parent)
 
-	def set(self, arg_0: enums.HcpyFormat) -> None:
+	def set(self, format_py: enums.HcpyFormat) -> None:
 		"""SCPI: HCOPy:FORMat \n
-		Snippet: driver.hardCopy.formatPy.set(arg_0 = enums.HcpyFormat.BMP) \n
+		Snippet: driver.hardCopy.formatPy.set(format_py = enums.HcpyFormat.BMP) \n
 		No command help available \n
-			:param arg_0: No help available
+			:param format_py: No help available
 		"""
-		param = Conversions.enum_scalar_to_str(arg_0, enums.HcpyFormat)
+		param = Conversions.enum_scalar_to_str(format_py, enums.HcpyFormat)
 		self._core.io.write(f'HCOPy:FORMat {param}')
 
 	# noinspection PyTypeChecker
-	def get(self, arg_0: enums.HcpyFormat) -> enums.HcpyFormat:
+	def get(self, format_py: enums.HcpyFormat) -> enums.HcpyFormat:
 		"""SCPI: HCOPy:FORMat \n
-		Snippet: value: enums.HcpyFormat = driver.hardCopy.formatPy.get(arg_0 = enums.HcpyFormat.BMP) \n
+		Snippet: value: enums.HcpyFormat = driver.hardCopy.formatPy.get(format_py = enums.HcpyFormat.BMP) \n
 		No command help available \n
-			:param arg_0: No help available
-			:return: arg_0: No help available"""
-		param = Conversions.enum_scalar_to_str(arg_0, enums.HcpyFormat)
+			:param format_py: No help available
+			:return: format_py: No help available"""
+		param = Conversions.enum_scalar_to_str(format_py, enums.HcpyFormat)
 		response = self._core.io.query_str(f'HCOPy:FORMat? {param}')
 		return Conversions.str_to_scalar_enum(response, enums.HcpyFormat)
