@@ -14,7 +14,7 @@ class Select:
 	def set(self, channel: int) -> None:
 		"""SCPI: INSTrument:NSELect \n
 		Snippet: driver.instrument.select.set(channel = 1) \n
-		No command help available \n
+		Selects or queries the channel by number. \n
 			:param channel: No help available
 		"""
 		param = Conversions.decimal_value_to_str(channel)
@@ -23,7 +23,7 @@ class Select:
 	def get(self) -> int:
 		"""SCPI: INSTrument:NSELect \n
 		Snippet: value: int = driver.instrument.select.get() \n
-		No command help available \n
+		Selects or queries the channel by number. \n
 			:return: channel: No help available"""
 		response = self._core.io.query_str(f'INSTrument:NSELect?')
 		return Conversions.str_to_int(response)
