@@ -17,7 +17,7 @@ class Usb:
 		"""SCPI: INTerfaces:USB:CLASs \n
 		Snippet: value: enums.UsbClass = driver.interfaces.usb.get_class() \n
 		Sets or queries the USB class. \n
-			:return: arg_0: CDC | TMC CDC USB CDC connection. TMC USB TMC connection.
+			:return: arg_0: No help available
 		"""
 		response = self._core.io.query_str('INTerfaces:USB:CLASs?')
 		return Conversions.str_to_scalar_enum(response, enums.UsbClass)
@@ -26,7 +26,8 @@ class Usb:
 		"""SCPI: INTerfaces:USB:CLASs \n
 		Snippet: driver.interfaces.usb.set_class(arg_0 = enums.UsbClass.CDC) \n
 		Sets or queries the USB class. \n
-			:param arg_0: CDC | TMC CDC USB CDC connection. TMC USB TMC connection.
-		"""
+			:param arg_0:
+				- CDC: USB CDC connection.
+				- TMC: USB TMC connection."""
 		param = Conversions.enum_scalar_to_str(arg_0, enums.UsbClass)
 		self._core.io.write(f'INTerfaces:USB:CLASs {param}')
