@@ -15,7 +15,7 @@ class Fname:
 	def set(self, set_new_value: str) -> None:
 		"""SCPI: LOG:FNAMe \n
 		Snippet: driver.log.fname.set(set_new_value = '1') \n
-		Queries the filename and storage location for the data logging. \n
+		Sets or queries the filename and storage location for the data logging. \n
 			:param set_new_value: No help available
 		"""
 		param = Conversions.value_to_quoted_str(set_new_value)
@@ -24,7 +24,7 @@ class Fname:
 	def get(self) -> str:
 		"""SCPI: LOG:FNAMe \n
 		Snippet: value: str = driver.log.fname.get() \n
-		Queries the filename and storage location for the data logging. \n
+		Sets or queries the filename and storage location for the data logging. \n
 			:return: set_new_value: No help available"""
 		response = self._core.io.query_str(f'LOG:FNAMe?')
 		return trim_str_response(response)
