@@ -24,7 +24,8 @@ class General:
 		"""SCPI: OUTPut:GENeral[:STATe] \n
 		Snippet: driver.output.general.set_state(arg_0 = False) \n
 		Sets or queries all previous selected channels simultaneously \n
-			:param arg_0: 0 Switches off previous selected channels simultaneously. 1 Switches on previous selected channels simultaneously.
-		"""
+			:param arg_0:
+				- 0: Switches off previous selected channels simultaneously.
+				- 1: Switches on previous selected channels simultaneously."""
 		param = Conversions.bool_to_str(arg_0)
 		self._core.io.write_with_opc(f'OUTPut:GENeral:STATe {param}')
