@@ -24,7 +24,8 @@ class Alimit:
 		"""SCPI: [SOURce]:ALIMit[:STATe] \n
 		Snippet: driver.source.alimit.set_state(arg_0 = False) \n
 		Sets or queries the safety limit state. \n
-			:param arg_0: No help available
-		"""
+			:param arg_0:
+				- 1: Activates the safety limit.
+				- 0: Deactivates the safety limit."""
 		param = Conversions.bool_to_str(arg_0)
 		self._core.io.write(f'SOURce:ALIMit:STATe {param}')
