@@ -15,8 +15,10 @@ class Lower:
 		"""SCPI: [SOURce]:CURRent[:LEVel][:IMMediate]:ALIMit:LOWer \n
 		Snippet: driver.source.current.level.immediate.alimit.lower.set(current = 1.0) \n
 		Sets or queries the lower safety limit for current. \n
-			:param current: numeric value | MIN | MINimum | MAX | MAXimum | list numeric value Numeric value for lower safety limit. MIN | MINimum Min value for lower safety limit. MAX | MAXimum Max value for lower safety limit. Range: For up to 6V: 0.001E+00 to 3.010E+00. For above 6V: 0.001E+00 to 6.010E+00
-		"""
+			:param current:
+				- numeric value: Numeric value for lower safety limit.
+				- MIN | MINimum: Min value for lower safety limit.
+				- MAX | MAXimum: Max value for lower safety limit."""
 		param = Conversions.decimal_value_to_str(current)
 		self._core.io.write(f'SOURce:CURRent:LEVel:IMMediate:ALIMit:LOWer {param}')
 
