@@ -14,8 +14,8 @@ class Link:
 	def set(self, arg_0: int) -> None:
 		"""SCPI: [SOURce]:CURRent:PROTection:LINK \n
 		Snippet: driver.source.current.protection.link.set(arg_0 = 1) \n
-		No command help available \n
-			:param arg_0: No help available
+		Sets or queries the fuses of several selected channels (fuse linking) . \n
+			:param arg_0: 1 | 2
 		"""
 		param = Conversions.decimal_value_to_str(arg_0)
 		self._core.io.write(f'SOURce:CURRent:PROTection:LINK {param}')
@@ -23,9 +23,9 @@ class Link:
 	def get(self, arg_0: int) -> int:
 		"""SCPI: [SOURce]:CURRent:PROTection:LINK \n
 		Snippet: value: int = driver.source.current.protection.link.get(arg_0 = 1) \n
-		No command help available \n
-			:param arg_0: No help available
-			:return: arg_0: No help available"""
+		Sets or queries the fuses of several selected channels (fuse linking) . \n
+			:param arg_0: 1 | 2
+			:return: arg_0: 1 | 2"""
 		param = Conversions.decimal_value_to_str(arg_0)
 		response = self._core.io.query_str(f'SOURce:CURRent:PROTection:LINK? {param}')
 		return Conversions.str_to_int(response)
