@@ -15,8 +15,10 @@ class Lower:
 		"""SCPI: [SOURce]:VOLTage[:LEVel][:IMMediate]:ALIMit:LOWer \n
 		Snippet: driver.source.voltage.level.immediate.alimit.lower.set(voltage = 1.0) \n
 		Sets or queries the lower safety limit for voltage. \n
-			:param voltage: numeric value | MIN | MINimum | MAX | MAXimum | list numeric vaule Numeric value for safety limit. MIN | MINimum Min value for lower safety limit. MAX | MAXimum Max value for lower safety limit. Range: 0.000E+00 to 2.050E+01
-		"""
+			:param voltage:
+				- numeric value: Numeric value for safety limit.
+				- MIN | MINimum: Min value for lower safety limit.
+				- MAX | MAXimum: Max value for lower safety limit."""
 		param = Conversions.decimal_value_to_str(voltage)
 		self._core.io.write(f'SOURce:VOLTage:LEVel:IMMediate:ALIMit:LOWer {param}')
 
