@@ -15,8 +15,10 @@ class Upper:
 		"""SCPI: [SOURce]:VOLTage[:LEVel][:IMMediate]:ALIMit[:UPPer] \n
 		Snippet: driver.source.voltage.level.immediate.alimit.upper.set(current = 1.0) \n
 		Sets or queries the upper safety limit for voltage. \n
-			:param current: No help available
-		"""
+			:param current:
+				- numeric value: Numeric value for upper safety limit.
+				- MIN | MINimum: Min value for upper safety limit.
+				- MAX | MAXimum: Max value for upper safety limit."""
 		param = Conversions.decimal_value_to_str(current)
 		self._core.io.write(f'SOURce:VOLTage:LEVel:IMMediate:ALIMit:UPPer {param}')
 
