@@ -18,7 +18,7 @@ class Condition:
 		Returns the contents of the CONDition part of the status register to check for questionable instrument or measurement
 		states. Reading the CONDition registers does not delete the contents. \n
 			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Isummary')
-			:return: result: No help available"""
+			:return: result: Condition bits in decimal representation"""
 		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
 		response = self._core.io.query_str(f'STATus:QUEStionable:INSTrument:ISUMmary{channel_cmd_val}:CONDition?')
 		return Conversions.str_to_int(response)
