@@ -18,7 +18,7 @@ class Event:
 		Returns the contents of the EVENt part of the status register to check whether an event has occurred since the last
 		reading. Reading an EVENt register deletes its contents. \n
 			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Isummary')
-			:return: result: No help available"""
+			:return: result: Event bits in decimal representation"""
 		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
 		response = self._core.io.query_str(f'STATus:QUEStionable:INSTrument:ISUMmary{channel_cmd_val}:EVENt?')
 		return Conversions.str_to_int(response)
