@@ -4,7 +4,7 @@ from ...Internal.CommandsGroup import CommandsGroup
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
 class Beeper:
-	"""Beeper commands group definition. 7 total commands, 4 Sub-groups, 0 group commands"""
+	"""Beeper commands group definition. 8 total commands, 5 Sub-groups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -26,6 +26,14 @@ class Beeper:
 			self._current = Current(self._core, self._base)
 		return self._current
 
+	@property
+	def output(self):
+		"""output commands group. 0 Sub-classes, 1 commands."""
+		if not hasattr(self, '_output'):
+			from .Beeper_.Output import Output
+			self._output = Output(self._core, self._base)
+		return self._output
+
 	@property
 	def complete(self):
 		"""complete commands group. 1 Sub-classes, 1 commands."""
