@@ -23,16 +23,16 @@ class Complete:
 		"""SCPI: SYSTem:BEEPer[:COMPlete]:STATe \n
 		Snippet: value: bool = driver.system.beeper.complete.get_state() \n
 		Sets or queries the beeper tone. \n
-			:return: arg_0: No help available
+			:return: beeper_state: No help available
 		"""
 		response = self._core.io.query_str('SYSTem:BEEPer:COMPlete:STATe?')
 		return Conversions.str_to_bool(response)
 
-	def set_state(self, arg_0: bool) -> None:
+	def set_state(self, beeper_state: bool) -> None:
 		"""SCPI: SYSTem:BEEPer[:COMPlete]:STATe \n
-		Snippet: driver.system.beeper.complete.set_state(arg_0 = False) \n
+		Snippet: driver.system.beeper.complete.set_state(beeper_state = False) \n
 		Sets or queries the beeper tone. \n
-			:param arg_0: 1 Control beeper is activated. 0 Control beeper is deactivated.
+			:param beeper_state: 1 | 0 ON OFF - Control beeper is deactivated. OFF ON - Control beeper is activated.
 		"""
-		param = Conversions.bool_to_str(arg_0)
+		param = Conversions.bool_to_str(beeper_state)
 		self._core.io.write(f'SYSTem:BEEPer:COMPlete:STATe {param}')
