@@ -14,8 +14,8 @@ class Current:
 	def get_state(self) -> bool:
 		"""SCPI: SYSTem:BEEPer:CURRent:STATe \n
 		Snippet: value: bool = driver.system.beeper.current.get_state() \n
-		Enables or disables beep sound for 'current control' alert. \n
-			:return: arg_0: 1 Enables the 'Current control' beep sound, a continuous beep sound alert when the selected output channel goes into CC mode. 0 Disables the 'Current control' beep sound.
+		Sets or queries current control beeper tone state. \n
+			:return: arg_0: No help available
 		"""
 		response = self._core.io.query_str('SYSTem:BEEPer:CURRent:STATe?')
 		return Conversions.str_to_bool(response)
@@ -23,8 +23,9 @@ class Current:
 	def set_state(self, arg_0: bool) -> None:
 		"""SCPI: SYSTem:BEEPer:CURRent:STATe \n
 		Snippet: driver.system.beeper.current.set_state(arg_0 = False) \n
-		Enables or disables beep sound for 'current control' alert. \n
-			:param arg_0: 1 Enables the 'Current control' beep sound, a continuous beep sound alert when the selected output channel goes into CC mode. 0 Disables the 'Current control' beep sound.
-		"""
+		Sets or queries current control beeper tone state. \n
+			:param arg_0:
+				- 1: Control beeper is activated.
+				- 0: Control beeper is deactivated."""
 		param = Conversions.bool_to_str(arg_0)
 		self._core.io.write(f'SYSTem:BEEPer:CURRent:STATe {param}')
