@@ -22,8 +22,8 @@ class Protection:
 	def get_state(self) -> bool:
 		"""SCPI: SYSTem:BEEPer:PROTection:STATe \n
 		Snippet: value: bool = driver.system.beeper.protection.get_state() \n
-		Enables or disables beep sound for 'protection' alert. \n
-			:return: arg_0: 1 Enables the 'protection' beep sound, a single beep alert when a fuse tripped occurs. 0 Disables the 'protection' beep sound.
+		Sets or queries protection beeper tone state. \n
+			:return: arg_0: No help available
 		"""
 		response = self._core.io.query_str('SYSTem:BEEPer:PROTection:STATe?')
 		return Conversions.str_to_bool(response)
@@ -31,8 +31,9 @@ class Protection:
 	def set_state(self, arg_0: bool) -> None:
 		"""SCPI: SYSTem:BEEPer:PROTection:STATe \n
 		Snippet: driver.system.beeper.protection.set_state(arg_0 = False) \n
-		Enables or disables beep sound for 'protection' alert. \n
-			:param arg_0: 1 Enables the 'protection' beep sound, a single beep alert when a fuse tripped occurs. 0 Disables the 'protection' beep sound.
-		"""
+		Sets or queries protection beeper tone state. \n
+			:param arg_0:
+				- 1: Protection beeper is activated.
+				- 0: Protection beeper is deactivated."""
 		param = Conversions.bool_to_str(arg_0)
 		self._core.io.write(f'SYSTem:BEEPer:PROTection:STATe {param}')
