@@ -13,14 +13,14 @@ class Immediate:
 	def set(self) -> None:
 		"""SCPI: SYSTem:BEEPer:PROTection[:IMMediate] \n
 		Snippet: driver.system.beeper.protection.immediate.set() \n
-		Return a single 'protection' beep sound immediately. \n
+		Returns a single protection beep immediately. \n
 		"""
 		self._core.io.write(f'SYSTem:BEEPer:PROTection:IMMediate')
 
 	def set_with_opc(self) -> None:
 		"""SCPI: SYSTem:BEEPer:PROTection[:IMMediate] \n
 		Snippet: driver.system.beeper.protection.immediate.set_with_opc() \n
-		Return a single 'protection' beep sound immediately. \n
+		Returns a single protection beep immediately. \n
 		Same as set, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
 		"""
 		self._core.io.write_with_opc(f'SYSTem:BEEPer:PROTection:IMMediate')
