@@ -22,17 +22,18 @@ class WarningPy:
 	def get_state(self) -> bool:
 		"""SCPI: SYSTem:BEEPer:WARNing:STATe \n
 		Snippet: value: bool = driver.system.beeper.warningPy.get_state() \n
-		No command help available \n
-			:return: arg_0: No help available
+		Sets or queries 'error/warning' beeper tone state. \n
+			:return: warning_beep_state: No help available
 		"""
 		response = self._core.io.query_str('SYSTem:BEEPer:WARNing:STATe?')
 		return Conversions.str_to_bool(response)
 
-	def set_state(self, arg_0: bool) -> None:
+	def set_state(self, warning_beep_state: bool) -> None:
 		"""SCPI: SYSTem:BEEPer:WARNing:STATe \n
-		Snippet: driver.system.beeper.warningPy.set_state(arg_0 = False) \n
-		No command help available \n
-			:param arg_0: No help available
-		"""
-		param = Conversions.bool_to_str(arg_0)
+		Snippet: driver.system.beeper.warningPy.set_state(warning_beep_state = False) \n
+		Sets or queries 'error/warning' beeper tone state. \n
+			:param warning_beep_state:
+				- 1: Beep sound for 'error/warning' is enabled.
+				- 0: Beep sound for 'error/warning' is disabled."""
+		param = Conversions.bool_to_str(warning_beep_state)
 		self._core.io.write(f'SYSTem:BEEPer:WARNing:STATe {param}')
