@@ -13,14 +13,14 @@ class Immediate:
 	def set(self) -> None:
 		"""SCPI: SYSTem:BEEPer:WARNing[:IMMediate] \n
 		Snippet: driver.system.beeper.warningPy.immediate.set() \n
-		No command help available \n
+		Returns a single 'error/warning' beep immediately. \n
 		"""
 		self._core.io.write(f'SYSTem:BEEPer:WARNing:IMMediate')
 
 	def set_with_opc(self) -> None:
 		"""SCPI: SYSTem:BEEPer:WARNing[:IMMediate] \n
 		Snippet: driver.system.beeper.warningPy.immediate.set_with_opc() \n
-		No command help available \n
+		Returns a single 'error/warning' beep immediately. \n
 		Same as set, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
 		"""
 		self._core.io.write_with_opc(f'SYSTem:BEEPer:WARNing:IMMediate')
