@@ -15,16 +15,16 @@ class Key:
 		"""SCPI: SYSTem:KEY:BRIGhtness \n
 		Snippet: value: float = driver.system.key.get_brightness() \n
 		Sets or queries the front panel key brightness. \n
-			:return: arg_0: No help available
+			:return: front_key_brightness: No help available
 		"""
 		response = self._core.io.query_str('SYSTem:KEY:BRIGhtness?')
 		return Conversions.str_to_float(response)
 
-	def set_brightness(self, arg_0: float) -> None:
+	def set_brightness(self, front_key_brightness: float) -> None:
 		"""SCPI: SYSTem:KEY:BRIGhtness \n
-		Snippet: driver.system.key.set_brightness(arg_0 = 1.0) \n
+		Snippet: driver.system.key.set_brightness(front_key_brightness = 1.0) \n
 		Sets or queries the front panel key brightness. \n
-			:param arg_0: Sets the key brightness. Range: 0.0 to 1.0
+			:param front_key_brightness: Sets the key brightness.
 		"""
-		param = Conversions.decimal_value_to_str(arg_0)
+		param = Conversions.decimal_value_to_str(front_key_brightness)
 		self._core.io.write(f'SYSTem:KEY:BRIGhtness {param}')
