@@ -13,18 +13,14 @@ class Local:
 	def set(self) -> None:
 		"""SCPI: SYSTem:LOCal \n
 		Snippet: driver.system.local.set() \n
-		Sets the system to front panel control. The front panel control is unlocked. If the front panel control was locked with
-		the SCPI command method RsNgx.System.RwLock.set, the message box of the locked front panel on the instrument display will
-		be disappeared. \n
+		Sets the system to front panel control. The front panel control is unlocked. \n
 		"""
 		self._core.io.write(f'SYSTem:LOCal')
 
 	def set_with_opc(self) -> None:
 		"""SCPI: SYSTem:LOCal \n
 		Snippet: driver.system.local.set_with_opc() \n
-		Sets the system to front panel control. The front panel control is unlocked. If the front panel control was locked with
-		the SCPI command method RsNgx.System.RwLock.set, the message box of the locked front panel on the instrument display will
-		be disappeared. \n
+		Sets the system to front panel control. The front panel control is unlocked. \n
 		Same as set, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
 		"""
 		self._core.io.write_with_opc(f'SYSTem:LOCal')
