@@ -13,16 +13,14 @@ class Remote:
 	def set(self) -> None:
 		"""SCPI: SYSTem:REMote \n
 		Snippet: driver.system.remote.set() \n
-		Sets the system to remote state. The front panel control is locked. By pushing the softkey button [*] key, the front
-		panel control will be activated. \n
+		Sets the system to remote state. The front panel control is locked. \n
 		"""
 		self._core.io.write(f'SYSTem:REMote')
 
 	def set_with_opc(self) -> None:
 		"""SCPI: SYSTem:REMote \n
 		Snippet: driver.system.remote.set_with_opc() \n
-		Sets the system to remote state. The front panel control is locked. By pushing the softkey button [*] key, the front
-		panel control will be activated. \n
+		Sets the system to remote state. The front panel control is locked. \n
 		Same as set, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
 		"""
 		self._core.io.write_with_opc(f'SYSTem:REMote')
