@@ -11,13 +11,13 @@ class Default:
 		self._core = core
 		self._base = CommandsGroup("default", core, parent)
 
-	def save(self, arg_0: str = None) -> None:
+	def save(self, file_path: str = None) -> None:
 		"""SCPI: SYSTem:SETTing:DEFault:SAVE \n
-		Snippet: driver.system.setting.default.save(arg_0 = '1') \n
+		Snippet: driver.system.setting.default.save(file_path = '1') \n
 		No command help available \n
-			:param arg_0: No help available
+			:param file_path: No help available
 		"""
 		param = ''
-		if arg_0:
-			param = Conversions.value_to_quoted_str(arg_0)
+		if file_path:
+			param = Conversions.value_to_quoted_str(file_path)
 		self._core.io.write(f'SYSTem:SETTing:DEFault:SAVE {param}'.strip())
