@@ -1,10 +1,10 @@
 """RsNgx instrument driver
-	:version: 3.0.0.40
+	:version: 3.1.0.48
 	:copyright: 2021 by Rohde & Schwarz GMBH & Co. KG
 	:license: MIT, see LICENSE for more details.
 """
 
-__version__ = '3.0.0.40'
+__version__ = '3.1.0.48'
 
 # Main class
 from RsNgx.RsNgx import RsNgx
@@ -18,6 +18,9 @@ from RsNgx.Internal.InstrumentErrors import RsInstrException, TimeoutException,
 # Callback Event Argument prototypes
 from RsNgx.Internal.IoTransferEventArgs import IoTransferEventArgs
 
+# Logging Mode
+from RsNgx.Internal.ScpiLogger import LoggingMode
+
 # enums
 from RsNgx import enums
 
